<?php

namespace Litepie\Team\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litepie\Team\Actions\TeamAction;
use Litepie\Team\Http\Requests\TeamActionRequest;
use Litepie\Team\Http\Resources\TeamResource;
use Litepie\Team\Models\Team;

/**
 * Admin web controller class.
 */
class TeamActionController extends BaseController
{

    /**
     * Action controller function for team.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TeamActionRequest $request, Team $team, $action)
    {
        try {
            $request = $request->all();
            $team = TeamAction::run($action, $team, $request);

            $data = new TeamResource($team);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('team::team.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('team/team/' . $team->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('team/team/' . $team->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
