<?php

namespace Litepie\Team\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litepie\Team\Http\Resources\TeamResource;
use Litepie\Team\Http\Resources\TeamsCollection;
use Litepie\Team\Scopes\TeamPublicScope;
use Litepie\Team\Models\Team;

class TeamPublicController extends BaseController
{

    /**
     * Show team's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Team::pushScope(new RequestScope())
            ->pushScope(new TeamPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $teams = new TeamsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('team::team.names'))
            ->view('team::public.team.index')
            ->data(compact('teams', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show team.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Team::findBySlug($slug);
        $data = new TeamResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('team::team.name'))
            ->view('team::public.team.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
