<?php

namespace Litepie\Team\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litepie\Team\Actions\TeamReport;
use Litepie\Team\Http\Requests\TeamReportRequest;

/**
 * Admin web controller class.
 */
class TeamReportController extends BaseController
{
    /**
     * Action controller function for team.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TeamReportRequest $request, $report)
    {
        try {
        
            $this->model = app(Team::class);
            $data = TeamReport::run($request, $report);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('team::team.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('team/team/' . $report))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('team/team/' . $report))
                ->redirect();
        }
    }
}
