<?php

namespace Litepie\Team\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litepie\Team\Actions\UserAction;
use Litepie\Team\Http\Requests\UserActionRequest;
use Litepie\Team\Http\Resources\UserResource;
use Litepie\Team\Models\User;

/**
 * Admin web controller class.
 */
class UserActionController extends BaseController
{

    /**
     * Action controller function for user.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(UserActionRequest $request, User $user, $action)
    {
        try {
            $request = $request->all();
            $user = UserAction::run($action, $user, $request);

            $data = new UserResource($user);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('team::user.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('team/user/' . $user->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('team/user/' . $user->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
