<?php

namespace Litepie\Team\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litepie\Team\Events\TeamWorkflow as TeamWorkflowEvent;
use Litepie\Team\Notifications\TeamWorkflow as TeamWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TeamWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TeamWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $team is submitted.
     *
     * @param TeamWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TeamWorkflowEvent $event)
    {
        $client = $event->team->client;
        Notification::send($client, new TeamWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $team is published.
     *
     * @param TeamWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TeamWorkflowEvent $event)
    {
        $client = $event->team->client;
        Notification::send($client, new TeamWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $team is approved.
     *
     * @param TeamWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TeamWorkflowEvent $event)
    {
        $client = $event->team->client;
        Notification::send($client, new TeamWorkflowNotification($event));
    }

    /**
     * Handles the $team workflow event as a listener.
     *
     * @param TeamWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TeamWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
