<?php
namespace Litepie\Team\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litepie\Team\Events\TeamAction as TeamActionEvent;
use Litepie\Team\Models\Team;

class TeamAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $team;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TeamActionEvent $team
     */
    public function __construct(TeamActionEvent $team)
    {
        $this->action = $event->action;
        $this->team = $team;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Team Approved - ' . config('app.name'))
            ->view('team::team.email.action', ['data' => $this->team]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
