<?php
namespace Litepie\Team\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litepie\Team\Events\UserAction as UserActionEvent;
use Litepie\Team\Models\User;

class UserAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $user;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param UserActionEvent $user
     */
    public function __construct(UserActionEvent $user)
    {
        $this->action = $event->action;
        $this->user = $user;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('User Approved - ' . config('app.name'))
            ->view('team::user.email.action', ['data' => $this->user]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
